#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Helpers.DefaultNames import get_default_group_name
from icinga2confgen.Helpers.Namable import Nameable


class Group(Nameable):

    def __init__(self, id, type):
        Nameable.__init__(self)
        self.set_display_name(get_default_group_name(id))
        self.__id = id
        self.__type = type

    def get_id(self):
        return self.__id

    def get_custom_config(self):
        return ''

    def get_config(self):
        config = 'object ' + self.__type.capitalize() + 'Group "' + self.__type + 'group_' + self.get_id() + '" {\n'
        config += Nameable.get_config(self)
        config += self.get_custom_config()
        config += '  assign where "' + self.__type + 'group_' + self.get_id() + '" in ' + self.__type + '.groups\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.MySQLCommand import MySQLCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckMySQL(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckMySQL', 'mysql')
        self.__host = '127.0.0.1'
        self.__port = 3306
        self.__ignore_auth = False
        self.__socket = None
        self.__database = None
        self.__file = None
        self.__group = None
        self.__user = None
        self.__password = None
        self.__check_slave = False
        self.__slave_warning = None
        self.__slave_critical = None
        self.__use_ssl = False
        self.__ssl_ciphers = None
        self.__ca_cert = None
        self.__ca_dir = None
        self.__cert = None
        self.__key = None
        self.add_service_group(ServiceGroup.create('mysql'))
        self.add_service_group(ServiceGroup.create('database'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_ignore_auth(self, ignore_auth):
        ValueChecker.is_bool(ignore_auth)
        self.__ignore_auth = ignore_auth
        return self

    def get_ignore_auth(self):
        return self.__ignore_auth

    def set_socket(self, socket):
        ValueChecker.is_string(socket)
        self.__socket = socket
        return self

    def get_socket(self):
        return self.__socket

    def set_database(self, database):
        ValueChecker.is_string(database)
        self.__database = database
        return self

    def get_database(self):
        return self.__database

    def set_file(self, file):
        ValueChecker.is_string(file)
        self.__file = file
        return self

    def get_file(self):
        return self.__file

    def set_group(self, group):
        ValueChecker.is_string(group)
        self.__group = group
        return self

    def get_group(self):
        return self.__group

    def set_user(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user(self):
        return self.__user

    def set_password(self, password):
        ValueChecker.is_string(password)
        self.__password = password
        return self

    def get_password(self):
        return self.__password

    def set_check_slave(self, check_slave):
        ValueChecker.is_bool(check_slave)
        self.__check_slave = check_slave
        return self

    def get_check_slave(self):
        return self.__check_slave

    def set_slave_warning(self, slave_warning):
        ValueChecker.is_string(slave_warning)
        self.__slave_warning = slave_warning
        return self

    def get_slave_warning(self):
        return self.__slave_warning

    def set_slave_critical(self, slave_critical):
        ValueChecker.is_string(slave_critical)
        self.__slave_critical = slave_critical
        return self

    def get_slave_critical(self):
        return self.__slave_critical

    def set_use_ssl(self, use_ssl):
        ValueChecker.is_bool(use_ssl)
        self.__use_ssl = use_ssl
        return self

    def get_use_ssl(self):
        return self.__use_ssl

    def set_ssl_ciphers(self, ssl_ciphers):
        ValueChecker.is_string(ssl_ciphers)
        self.__ssl_ciphers = ssl_ciphers
        return self

    def get_ssl_ciphers(self):
        return self.__ssl_ciphers

    def set_ca_cert(self, ca_cert):
        ValueChecker.is_string(ca_cert)
        self.__ca_cert = ca_cert
        return self

    def get_ca_cert(self):
        return self.__ca_cert

    def set_ca_dir(self, ca_dir):
        ValueChecker.is_string(ca_dir)
        self.__ca_dir = ca_dir
        return self

    def get_ca_dir(self):
        return self.__ca_dir

    def set_cert(self, cert):
        ValueChecker.is_string(cert)
        self.__cert = cert
        return self

    def get_cert(self):
        return self.__cert

    def set_key(self, key):
        ValueChecker.is_string(key)
        self.__key = key
        return self

    def get_key(self):
        return self.__key

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckMySQL(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('mysql'):
            MySQLCommand.create('mysql')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.LogCommand import LogCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckLog(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckLog', 'log')
        self.__file = None
        self.__oldfile = None
        self.__query = None
        self.add_service_group(ServiceGroup.create('log'))

    def set_file(self, file):
        ValueChecker.is_string(file)
        self.__file = file
        return self

    def get_file(self):
        return self.__file

    def set_oldfile(self, oldfile):
        ValueChecker.is_string(oldfile)
        self.__oldfile = oldfile
        return self

    def get_oldfile(self):
        return self.__oldfile

    def set_query(self, query):
        ValueChecker.is_string(query)
        self.__query = query
        return self

    def get_query(self):
        return self.__query

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckLog(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('log'):
            LogCommand.create('log')

        return check

    def validate(self):
        if None is self.__file:
            raise Exception('You have to specify a file for ' + self.get_id())
        if None is self.__oldfile:
            raise Exception('You have to specify a old file for ' + self.get_id())
        if None is self.__query:
            raise Exception('You have to specify a query file for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.PgSQLCommand import PgSQLCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckPgSQL(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckPgSQL', 'pgsql')
        self.__host = None
        self.__port = 5432
        self.__database = None
        self.__logname = None
        self.__password = None
        self.__option = None
        self.__warning = None
        self.__critical = None
        self.__timeout = 10
        self.__query = None
        self.__warning_range = None
        self.__critical_range = None
        self.add_service_group(ServiceGroup.create('postgres'))
        self.add_service_group(ServiceGroup.create('database'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_database(self, database):
        ValueChecker.is_string(database)
        self.__database = database
        return self

    def get_database(self):
        return self.__database

    def set_logname(self, logname):
        ValueChecker.is_string(logname)
        self.__logname = logname
        return self

    def get_logname(self):
        return self.__logname

    def set_password(self, password):
        ValueChecker.is_string(password)
        self.__password = password
        return self

    def get_password(self):
        return self.__password

    def set_option(self, option):
        ValueChecker.is_string(option)
        self.__option = option
        return self

    def get_option(self):
        return self.__option

    def set_warning(self, warning):
        ValueChecker.is_number(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_number(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_query(self, query):
        ValueChecker.is_string(query)
        self.__query = query
        return self

    def get_query(self):
        return self.__query

    def set_warning_range(self, warning_range):
        ValueChecker.is_string(warning_range)
        self.__warning_range = warning_range
        return self

    def get_warning_range(self):
        return self.__warning_range

    def set_critical_range(self, critical_range):
        ValueChecker.is_string(critical_range)
        self.__critical_range = critical_range
        return self

    def get_critical_range(self):
        return self.__critical_range

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckPgSQL(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('pgsql'):
            PgSQLCommand.create('pgsql')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Commands.Command import Command
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class IfStatusCommand(Command):

    def __init__(self, id):
        Command.__init__(self, id)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_command(id)
        if None is command:
            command = IfStatusCommand(id)
            ConfigBuilder.add_command(id, command)

        return command

    def get_command(self):
        return 'check_ifstatus'

    def get_arguments(self):
        config = """{
    "-H" = {
      value = "$command_ifstatus_host$"
      required = true
    }
    "-p" = {
      value = "$command_ifstatus_port$"
      required = true
    }
    "-C" = {
      value = "$command_ifstatus_community$"
      required = true
    }
    "-v" = {
      value = "$command_ifstatus_snmp_version$"
      set_if = {{ macro("$command_ifstatus_snmp_version$") != false }}
    }
    "-I" = {
      set_if = "$command_ifstatus_if_mib$"
    }
    "-x" = {
      value = "$command_ifstatus_snmp_exclude$"
      set_if = {{ macro("$command_ifstatus_snmp_exclude$") != false }}
    }
    "-n" = {
      value = "$command_ifstatus_unused_ports_by_name$"
      set_if = {{ macro("$command_ifstatus_unused_ports_by_name$") != false }}
    }
    "-u" = {
      value = "$command_ifstatus_unused_ports$"
      set_if = {{ macro("$command_ifstatus_unused_ports$") != false }}
    }
    "-L" = {
      value = "$command_ifstatus_seclevel$"
      set_if = {{ macro("$command_ifstatus_seclevel$") != false }}
    }
    "-U" = {
      value = "$command_ifstatus_secname$"
      set_if = {{ macro("$command_ifstatus_secname$") != false }}
    }
    "-c" = {
      value = "$command_ifstatus_context$"
      set_if = {{ macro("$command_ifstatus_context$") != false }}
    }
    "-A" = {
      value = "$command_ifstatus_authpass$"
      set_if = {{ macro("$command_ifstatus_authpass$") != false }}
    }
    "-a" = {
      value = "$command_ifstatus_authproto$"
      set_if = {{ macro("$command_ifstatus_authproto$") != false }}
    }
    "-X" = {
      value = "$command_ifstatus_privpass$"
      set_if = {{ macro("$command_ifstatus_privpass$") != false }}
    }
    "-P" = {
      value = "$command_ifstatus_privproto$"
      set_if = {{ macro("$command_ifstatus_privproto$") != false }}
    }
    "-M" = {
      value = "$command_ifstatus_max_msg_size$"
      set_if = {{ macro("$command_ifstatus_max_msg_size$") != false }}
    }
    "-t" = {
      value = "$command_ifstatus_timeout$"
      set_if = {{ macro("$command_ifstatus_timeout$") != false }}
    }
  }
"""

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.SIMAPCommand import SIMAPCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSIMAP(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSIMAP', 'simap')
        self.__host = None
        self.__port = None
        self.__ipv4 = False
        self.__ipv6 = False
        self.__escape = False
        self.__send = None
        self.__expect = None
        self.__all = False
        self.__quit = None
        self.__refuse_state = None
        self.__mismatch_state = None
        self.__jail = False
        self.__maxbytes = None
        self.__delay = None
        self.__cert_warning = 29
        self.__cert_critical = 15
        self.__cert = True
        self.__use_ssl = False
        self.__sni = None
        self.__warning_time = None
        self.__critical_time = None
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('imap'))
        self.add_service_group(ServiceGroup.create('mail'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_ipv4(self, ipv4):
        ValueChecker.is_bool(ipv4)
        self.__ipv4 = ipv4
        return self

    def get_ipv4(self):
        return self.__ipv4

    def set_ipv6(self, ipv6):
        ValueChecker.is_bool(ipv6)
        self.__ipv6 = ipv6
        return self

    def get_ipv6(self):
        return self.__ipv6

    def set_escape(self, escape):
        ValueChecker.is_bool(escape)
        self.__escape = escape
        return self

    def get_escape(self):
        return self.__escape

    def set_send(self, send):
        ValueChecker.is_string(send)
        self.__send = send
        return self

    def get_send(self):
        return self.__send

    def set_expect(self, expect):
        ValueChecker.is_string(expect)
        self.__expect = expect
        return self

    def get_expect(self):
        return self.__expect

    def set_all(self, all):
        ValueChecker.is_bool(all)
        self.__all = all
        return self

    def get_all(self):
        return self.__all

    def set_quit(self, quit):
        ValueChecker.is_string(quit)
        self.__quit = quit
        return self

    def get_quit(self):
        return self.__quit

    def set_refuse_state(self, refuse_state):
        ValueChecker.is_string(refuse_state)
        self.__refuse_state = refuse_state
        return self

    def get_refuse_state(self):
        return self.__refuse_state

    def set_mismatch_state(self, mismatch_state):
        ValueChecker.is_string(mismatch_state)
        self.__mismatch_state = mismatch_state
        return self

    def get_mismatch_state(self):
        return self.__mismatch_state

    def set_jail(self, jail):
        ValueChecker.is_bool(jail)
        self.__jail = jail
        return self

    def get_jail(self):
        return self.__jail

    def set_maxbytes(self, maxbytes):
        ValueChecker.is_number(maxbytes)
        self.__maxbytes = maxbytes
        return self

    def get_maxbytes(self):
        return self.__maxbytes

    def set_delay(self, delay):
        ValueChecker.is_number(delay)
        self.__delay = delay
        return self

    def get_delay(self):
        return self.__delay

    def set_cert_warning(self, cert_warning):
        ValueChecker.is_number(cert_warning)
        self.__cert_warning = cert_warning
        return self

    def get_cert_warning(self):
        return self.__cert_warning

    def set_cert_critical(self, cert_critical):
        ValueChecker.is_number(cert_critical)
        self.__cert_critical = cert_critical
        return self

    def get_cert_critical(self):
        return self.__cert_critical

    def set_cert(self, cert):
        ValueChecker.is_bool(cert)
        self.__cert = cert
        return self

    def get_cert(self):
        return self.__cert

    def set_use_ssl(self, use_ssl):
        ValueChecker.is_bool(use_ssl)
        self.__use_ssl = use_ssl
        return self

    def get_use_ssl(self):
        return self.__use_ssl

    def set_sni(self, sni):
        ValueChecker.is_string(sni)
        self.__sni = sni
        return self

    def get_sni(self):
        return self.__sni

    def set_warning_time(self, warning_time):
        ValueChecker.is_number(warning_time)
        self.__warning_time = warning_time
        return self

    def get_warning_time(self):
        return self.__warning_time

    def set_critical_time(self, critical_time):
        ValueChecker.is_number(critical_time)
        self.__critical_time = critical_time
        return self

    def get_critical_time(self):
        return self.__critical_time

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSIMAP(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('simap'):
            SIMAPCommand.create('simap')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())
        if None is self.__port:
            raise Exception('You have to specify a port for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.SNMPCommand import SNMPCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSNMP(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSNMP', 'snmp')
        self.__over_ipv4 = False
        self.__over_ipv6 = False
        self.__host = None
        self.__port = 161
        self.__snmp_getnext = False
        self.__protocol = None
        self.__context = None
        self.__seclevel = None
        self.__authproto = None
        self.__privproto = None
        self.__community = None
        self.__username = None
        self.__authpassword = None
        self.__privpassword = None
        self.__oids = None
        self.__delimiter = None
        self.__warning = None
        self.__critical = None
        self.__rate = False
        self.__rate_multiplier = None
        self.__offset = None
        self.__string = None
        self.__ereg = None
        self.__invert = False
        self.__label = None
        self.__units = None
        self.__output_delimiter = None
        self.__timeout = 10
        self.__retries = 2
        self.__perf_oids = False
        self.add_service_group(ServiceGroup.create('snmp'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_over_ipv4(self, over_ipv4):
        ValueChecker.is_bool(over_ipv4)
        self.__over_ipv4 = over_ipv4
        return self

    def get_over_ipv4(self):
        return self.__over_ipv4

    def set_over_ipv6(self, over_ipv6):
        ValueChecker.is_bool(over_ipv6)
        self.__over_ipv6 = over_ipv6
        return self

    def get_over_ipv6(self):
        return self.__over_ipv6

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_string(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_snmp_getnext(self, snmp_getnext):
        ValueChecker.is_bool(snmp_getnext)
        self.__snmp_getnext = snmp_getnext
        return self

    def get_snmp_getnext(self):
        return self.__snmp_getnext

    def set_protocol(self, protocol):
        ValueChecker.is_string(protocol)
        self.__protocol = protocol
        return self

    def get_protocol(self):
        return self.__protocol

    def set_context(self, context):
        ValueChecker.is_string(context)
        self.__context = context
        return self

    def get_context(self):
        return self.__context

    def set_seclevel(self, seclevel):
        ValueChecker.is_string(seclevel)
        self.__seclevel = seclevel
        return self

    def get_seclevel(self):
        return self.__seclevel

    def set_authproto(self, authproto):
        ValueChecker.is_string(authproto)
        self.__authproto = authproto
        return self

    def get_authproto(self):
        return self.__authproto

    def set_privproto(self, privproto):
        ValueChecker.is_string(privproto)
        self.__privproto = privproto
        return self

    def get_privproto(self):
        return self.__privproto

    def set_community(self, community):
        ValueChecker.is_string(community)
        self.__community = community
        return self

    def get_community(self):
        return self.__community

    def set_username(self, username):
        ValueChecker.is_string(username)
        self.__username = username
        return self

    def get_username(self):
        return self.__username

    def set_authpassword(self, authpassword):
        ValueChecker.is_string(authpassword)
        self.__authpassword = authpassword
        return self

    def get_authpassword(self):
        return self.__authpassword

    def set_privpassword(self, privpassword):
        ValueChecker.is_string(privpassword)
        self.__privpassword = privpassword
        return self

    def get_privpassword(self):
        return self.__privpassword

    def set_oids(self, oids):
        ValueChecker.is_string(oids)
        self.__oids = oids
        return self

    def get_oids(self):
        return self.__oids

    def set_delimiter(self, delimiter):
        ValueChecker.is_string(delimiter)
        self.__delimiter = delimiter
        return self

    def get_delimiter(self):
        return self.__delimiter

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_rate(self, rate):
        ValueChecker.is_bool(rate)
        self.__rate = rate
        return self

    def get_rate(self):
        return self.__rate

    def set_rate_multiplier(self, rate_multiplier):
        ValueChecker.is_number(rate_multiplier)
        self.__rate_multiplier = rate_multiplier
        return self

    def get_rate_multiplier(self):
        return self.__rate_multiplier

    def set_offset(self, offset):
        ValueChecker.is_bool(offset)
        self.__offset = offset
        return self

    def get_offset(self):
        return self.__offset

    def set_string(self, string):
        ValueChecker.is_string(string)
        self.__string = string
        return self

    def get_string(self):
        return self.__string

    def set_ereg(self, ereg):
        ValueChecker.is_string(ereg)
        self.__ereg = ereg
        return self

    def get_ereg(self):
        return self.__ereg

    def set_invert(self, invert):
        ValueChecker.is_bool(invert)
        self.__invert = invert
        return self

    def get_invert(self):
        return self.__invert

    def set_label(self, label):
        ValueChecker.is_string(label)
        self.__label = label
        return self

    def get_label(self):
        return self.__label

    def set_units(self, units):
        ValueChecker.is_string(units)
        self.__units = units
        return self

    def get_units(self):
        return self.__units

    def set_output_delimiter(self, output_delimiter):
        ValueChecker.is_string(output_delimiter)
        self.__output_delimiter = output_delimiter
        return self

    def get_output_delimiter(self):
        return self.__output_delimiter

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_retries(self, retries):
        ValueChecker.is_number(retries)
        self.__retries = retries
        return self

    def get_retries(self):
        return self.__retries

    def set_perf_oids(self, perf_oids):
        ValueChecker.is_bool(perf_oids)
        self.__perf_oids = perf_oids
        return self

    def get_perf_oids(self):
        return self.__perf_oids

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSNMP(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('snmp'):
            SNMPCommand.create('snmp')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())
        if None is self.__oids:
            raise Exception('You have to specify a oids for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.LDAPSCommand import LDAPSCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckLDAPS(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckLDAPS', 'ldaps')
        self.__host = None
        self.__port = None
        self.__use_ipv4 = False
        self.__use_ipv6 = False
        self.__attr = None
        self.__base = None
        self.__dn = None
        self.__pass = None
        self.__starttls = False
        self.__ssl = True
        self.__protocol_v2 = False
        self.__protocol_v3 = False
        self.__warning = None
        self.__critical = None
        self.__warning_entries = None
        self.__critical_entries = None
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('ldap'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_use_ipv4(self, use_ipv4):
        ValueChecker.is_bool(use_ipv4)
        self.__use_ipv4 = use_ipv4
        return self

    def get_use_ipv4(self):
        return self.__use_ipv4

    def set_use_ipv6(self, use_ipv6):
        ValueChecker.is_bool(use_ipv6)
        self.__use_ipv6 = use_ipv6
        return self

    def get_use_ipv6(self):
        return self.__use_ipv6

    def set_attr(self, attr):
        ValueChecker.is_string(attr)
        self.__attr = attr
        return self

    def get_attr(self):
        return self.__attr

    def set_base(self, base):
        ValueChecker.is_string(base)
        self.__base = base
        return self

    def get_base(self):
        return self.__base

    def set_dn(self, dn):
        ValueChecker.is_string(dn)
        self.__dn = dn
        return self

    def get_dn(self):
        return self.__dn

    def set_pass(self, passwd):
        ValueChecker.is_string(passwd)
        self.__pass = passwd
        return self

    def get_pass(self):
        return self.__pass

    def set_starttls(self, starttls):
        ValueChecker.is_bool(starttls)
        self.__starttls = starttls
        return self

    def get_starttls(self):
        return self.__starttls

    def set_ssl(self, ssl):
        ValueChecker.is_bool(ssl)
        self.__ssl = ssl
        return self

    def get_ssl(self):
        return self.__ssl

    def set_protocol_v2(self, protocol_v2):
        ValueChecker.is_bool(protocol_v2)
        self.__protocol_v2 = protocol_v2
        return self

    def get_protocol_v2(self):
        return self.__protocol_v2

    def set_protocol_v3(self, protocol_v3):
        ValueChecker.is_bool(protocol_v3)
        self.__protocol_v3 = protocol_v3
        return self

    def get_protocol_v3(self):
        return self.__protocol_v3

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_warning_entries(self, warning_entries):
        ValueChecker.is_number(warning_entries)
        self.__warning_entries = warning_entries
        return self

    def get_warning_entries(self):
        return self.__warning_entries

    def set_critical_entries(self, critical_entries):
        ValueChecker.is_number(critical_entries)
        self.__critical_entries = critical_entries
        return self

    def get_critical_entries(self):
        return self.__critical_entries

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckLDAPS(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ldaps'):
            LDAPSCommand.create('ldaps')

        return check

    def validate(self):
        if None is self.__base:
            raise Exception('You have to specify a base dn for ' + self.get_id())
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Dependency.Dependency import Dependency
from icinga2confgen.Downtimes.ScheduledDowntime import ScheduledDowntime
from icinga2confgen.Helpers.Namable import Nameable
from icinga2confgen.Notification.Notification import Notification
from icinga2confgen.Servers.Zone import Zone
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class Checkable(Nameable):

    def __init__(self, is_check=True):
        Nameable.__init__(self)
        self.__is_check = is_check
        self.__max_check_attempts = 3
        self.__check_interval = '1m'
        self.__retry_interval = '15s'
        self.__enable_perfdata = True
        self.__notifications = []
        self.__downtimes = []
        self.__dependencies = []
        self.__dns_zone = Zone.create('master')
        self.__override_zone = False
        self.__command_endpoint = None
        self.__override_endpoint = False

    def set_max_check_attempts(self, max_check_attempts):
        ValueChecker.is_number(max_check_attempts)
        self.__max_check_attempts = max_check_attempts
        return self

    def get_max_check_attempts(self):
        return self.__max_check_attempts

    def set_check_interval(self, check_interval):
        ValueChecker.is_string(check_interval)
        self.__check_interval = check_interval
        return self

    def get_check_interval(self):
        return self.__check_interval

    def set_retry_interval(self, retry_interval):
        ValueChecker.is_string(retry_interval)
        self.__retry_interval = retry_interval
        return self

    def get_retry_interval(self):
        return self.__retry_interval

    def set_enable_perfdata(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__enable_perfdata = enabled
        return self

    def get_enable_perfdata(self):
        return self.__enable_perfdata

    def add_downtime(self, downtime):
        if isinstance(downtime, ScheduledDowntime):
            self.__downtimes.append(downtime)
        elif isinstance(downtime, str):
            downtime = ConfigBuilder.get_downtime(downtime)
            if None is downtime:
                raise Exception('Downtime does not exist yet!')
            self.__downtimes.append(downtime)
        else:
            raise Exception('Can only add Downtime or id of Downtime!')

        return self

    def remove_downtime(self, downtime):
        if isinstance(downtime, ScheduledDowntime):
            self.__downtimes.remove(downtime)
        elif isinstance(downtime, str):
            downtime = ConfigBuilder.get_downtime(downtime)
            self.__downtimes.remove(downtime)

        return self

    def get_downtimes(self):
        return self.__downtimes

    def add_dependency(self, dependency):
        if isinstance(dependency, Dependency):
            self.__dependencies.append(dependency)
        elif isinstance(dependency, str):
            dependency = ConfigBuilder.get_dependency(dependency)
            if None is dependency:
                raise Exception('Dependency does not exist yet!')
            self.__dependencies.append(dependency)
        else:
            raise Exception('Can only add Dependency or id of Dependency!')

        return self

    def remove_dependency(self, dependency):
        if isinstance(dependency, Dependency):
            self.__dependencies.remove(dependency)
        elif isinstance(dependency, str):
            dependency = ConfigBuilder.get_dependency(dependency)
            self.__dependencies.remove(dependency)

        return self

    def get_dependencies(self):
        return self.__dependencies

    def add_notification(self, notification):
        if isinstance(notification, Notification):
            self.__notifications.append(notification)
        elif isinstance(notification, str):
            notification = ConfigBuilder.get_notification(notification)
            if None is notification:
                raise Exception('Notification does not exist yet!')

            self.__notifications.append(notification)
        else:
            raise Exception('Can only add Notification or id of Notification!')
        return self

    def remove_notification(self, notification):

        if isinstance(notification, Notification):
            self.__notifications.remove(notification)

        elif isinstance(notification, str):
            notification = ConfigBuilder.get_notification(notification)
            self.__notifications.remove(notification)

        return self

    def get_notifications(self):
        return self.__notifications

    def set_zone(self, zone):
        if isinstance(zone, Zone):
            self.__dns_zone = zone
            self.__override_zone = True
        elif isinstance(zone, str):
            zone = ConfigBuilder.get_zone(zone)
            if None is zone:
                raise Exception('Zone does not exist yet!')
            self.__dns_zone = zone
            self.__override_zone = True
        else:
            raise Exception('Can only add Zone or id of Zone!')
        return self

    def get_zone(self):
        if self.__is_check and not self.__override_zone:
            return None

        return self.__dns_zone

    def set_endpoint(self, name):
        ValueChecker.is_string(name)
        self.__override_endpoint = True
        self.__command_endpoint = name
        return self

    def get_endpoint(self):
        return self.__command_endpoint

    def get_config(self):

        config = Nameable.get_config(self)
        if not self.__is_check:
            config += ValueMapper.parse_var('vars.zone_name', self.__dns_zone)
        elif self.__override_zone:
            config += ValueMapper.parse_var('zone', self.__dns_zone)
        else:
            config += '  zone = host.vars.zone_name\n'

        if not self.__is_check:
            config += ValueMapper.parse_var('vars.endpoint_name', self.__command_endpoint)
        elif self.__override_endpoint:
            config += ValueMapper.parse_var('command_endpoint', self.__command_endpoint)
        else:
            config += '  command_endpoint = host.vars.endpoint_name\n'

        config += '  check_interval = ' + self.__check_interval + '\n'
        config += '  retry_interval = ' + self.__retry_interval + '\n'
        config += ValueMapper.parse_var('max_check_attempts', self.__max_check_attempts)
        config += ValueMapper.parse_var('enable_perfdata', self.__enable_perfdata)
        config += ValueMapper.parse_var('vars.notification', self.__notifications, value_prefix='notification_')
        config += ValueMapper.parse_var('vars.downtime', self.__downtimes, value_prefix='downtime_')
        config += ValueMapper.parse_var('vars.dependencies', self.__dependencies, value_prefix='dependency_')

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class NotificationFunctions:

    def __init__(self):
        self.__email = []
        self.__phone = []
        self.__pager = []
        self.__telegram = []

    def add_email(self, email):
        ValueChecker.is_string(email)
        if email not in self.__email:
            self.__email.append(email)
        return self

    def remove_email(self, email):
        ValueChecker.is_string(email)
        self.__email.remove(email)
        return self

    def get_email(self):
        return self.__email

    def add_telegram_id(self, telegram_id):
        ValueChecker.is_number(telegram_id)
        if telegram_id not in self.__telegram:
            self.__telegram.append(telegram_id)
        return self

    def remove_telegram_id(self, telegram_id):
        ValueChecker.is_number(telegram_id)
        self.__telegram.remove(telegram_id)
        return self

    def get_telegram_id(self):
        return self.__telegram

    def add_pager(self, pager):
        ValueChecker.is_string(pager)
        if pager not in self.__pager:
            self.__pager.append(pager)
        return self

    def remove_pager(self, pager):
        ValueChecker.is_string(pager)
        self.__pager.remove(pager)
        return self

    def get_pager(self):
        return self.__pager

    def add_phone(self, phone):
        ValueChecker.is_string(phone)
        if phone not in self.__phone:
            self.__phone.append(phone)
        return self

    def get_phone(self):
        return self.__phone

    def remove_phone(self, phone):
        ValueChecker.is_string(phone)
        self.__phone.remove(phone)
        return self

    def get_config(self):
        config = ValueMapper.parse_var('vars.email_addresses', self.__email)
        config += ValueMapper.parse_var('pager', self.__pager)
        config += ValueMapper.parse_var('vars.phone', self.__phone)

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.HostGroup import HostGroup
from icinga2confgen.Helpers.Checkable import Checkable
from icinga2confgen.Helpers.CustomVars import CustomVars
from icinga2confgen.Helpers.PluginDirs import PluginDirs
from icinga2confgen.Helpers.ScriptDirs import ScriptDirs
from icinga2confgen.OS.OS import OS
from icinga2confgen.PackageManager.PackageManager import PackageManager
from icinga2confgen.Servers.SSHTemplate import SSHTemplate
from icinga2confgen.Servers.Zone import Zone
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class ServerTemplate(PluginDirs, ScriptDirs, Checkable, CustomVars):

    def __init__(self, id):
        CustomVars.__init__(self)
        PluginDirs.__init__(self)
        ScriptDirs.__init__(self)
        Checkable.__init__(self, is_check=False)
        self.__id = id
        self.__ipv4 = None
        self.__ipv6 = None
        self.__display_name = None
        self.__ssh_template = None
        self.__os = None
        self.__checks = []
        self.__templates = []
        self.__groups = []
        self.__package_manager = []
        self.__execution_zone = Zone.create('master')
        self.__execution_endpoint = None

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        template = None if force_create else ConfigBuilder.get_template(id)
        if None is template:
            template = ServerTemplate(id)
            ConfigBuilder.add_template(id, template)

        return template

    def get_id(self):
        return self.__id

    def set_execution_zone(self, zone):
        if isinstance(zone, Zone):
            self.__execution_zone = zone

        elif isinstance(zone, str):
            zone = ConfigBuilder.get_zone(zone)
            if None is zone:
                raise Exception('Zone does not exist yet!')
            self.__execution_zone = zone
        else:
            raise Exception('Can only add Zone or id of Zone!')

        return self

    def get_execution_zone(self):
        return self.__execution_zone

    def set_execution_endpoint(self, endpoint):
        ValueChecker.is_string(endpoint)
        self.__execution_endpoint = endpoint
        return self

    def get_execution_endpoint(self):
        return self.__execution_endpoint

    def set_ipv4(self, ip):
        ValueChecker.is_string(ip)
        self.__ipv4 = ip
        return self

    def get_ipv4(self):
        return self.__ipv4

    def set_ipv6(self, ip):
        ValueChecker.is_string(ip)
        self.__ipv6 = ip
        return self

    def get_ipv6(self):
        return self.__ipv6

    def set_ssh_template(self, ssh_template):

        if isinstance(ssh_template, SSHTemplate):
            self.__ssh_template = ssh_template

        elif isinstance(ssh_template, str):
            ssh_template = ConfigBuilder.get_ssh_template(ssh_template)
            if None is ssh_template:
                raise Exception('SSHTemplate does not exist yet!')
            self.__ssh_template = ssh_template
        else:
            raise Exception('Can only add SSHTemplate or id of SSHTemplate!')

        return self

    def get_ssh_template(self):

        return self.__ssh_template

    def set_os(self, os):

        if isinstance(os, OS):
            self.__os = os

        elif isinstance(os, str):
            os = ConfigBuilder.get_os(os)
            if None is os:
                raise Exception('OS does not exist yet!')
            self.__os = os
        else:
            raise Exception('Can only add OS or id of OS!')

        return self

    def get_os(self):

        return self.__os

    def add_check(self, check):
        if isinstance(check, Check):
            if check not in self.__checks:
                self.__checks.append(check)

        elif isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            if None is check:
                raise Exception('Check does not exist yet!')
            self.add_check(check)
        else:
            raise Exception('Can only add Check or id of Check!')

        return self

    def get_check(self):

        return self.__checks

    def remove_check(self, check):
        if isinstance(check, Check):
            self.__checks.remove(check)

        elif isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            self.__checks.remove(check)

        return self

    def add_template(self, template):
        if isinstance(template, ServerTemplate):
            if template not in self.__templates:
                self.__templates.append(template)

        elif isinstance(template, str):
            template = ConfigBuilder.get_template(template)
            if None is template:
                raise Exception('ServerTemplate does not exist yet!')
            self.add_template(template)
        else:
            raise Exception('Can only add ServerTemplate or id of ServerTemplate!')

        return self

    def remove_template(self, template):
        if isinstance(template, ServerTemplate):
            self.__templates.remove(template.get_id())
        elif isinstance(template, str):
            template = ConfigBuilder.get_template(template)
            self.__templates.remove(template)

        return self

    def get_templates(self):

        return self.__templates

    def add_hostgroup(self, group):
        if isinstance(group, HostGroup):
            if group not in self.__groups:
                self.__groups.append(group)
        elif isinstance(group, str):
            group = ConfigBuilder.get_hostgroup(group)
            if None is group:
                raise Exception('HostGroup does not exist yet!')
            self.add_hostgroup(group)
        else:
            raise Exception('Can only add HostGroup or id of HostGroup!')

        return self

    def get_hostgroups(self):
        return self.__groups

    def get_hostgroups_recursive(self):
        groups = self.__groups
        for template in self.__templates:
            groups += template.get_hostgroups()

        return groups

    def remove_hostgroup(self, group):
        if isinstance(group, HostGroup):
            self.__groups.remove(group)
        elif isinstance(group, str):
            group = ConfigBuilder.get_hostgroup(group)
            self.__groups.remove(group)

        return self

    def add_package_manager(self, package_manager):

        if isinstance(package_manager, PackageManager):
            if package_manager not in self.__package_manager:
                self.__package_manager.append(package_manager)

        elif isinstance(package_manager, str):
            package_manager = ConfigBuilder.get_package_manager(package_manager)
            if None is package_manager:
                raise Exception('PackageManager does not exist yet!')
            self.add_package_manager(package_manager)
        else:
            raise Exception('Can only add PackageManager or id of PackageManager!')

        return self

    def remove_package_manager(self, package_manager):

        if isinstance(package_manager, PackageManager):
            self.__package_manager.remove(package_manager)

        elif isinstance(package_manager, str):
            package_manager = ConfigBuilder.get_package_manager(package_manager)
            self.__package_manager.remove(package_manager)

        return self

    def get_package_managers(self):
        return self.__package_manager

    def get_config(self):
        config = 'template Host "servertemplate_' + self.__id + '" {\n'

        for template in self.__templates:
            config += '  import "servertemplate_' + template.get_id() + '"\n'

        if None is not self.__ssh_template:
            config += '  import "sshtemplate_' + self.__ssh_template.get_id() + '"\n'

        if None is not self.__os:
            config += '  import "os_' + self.__os.get_id() + '"\n'

        for manager in self.__package_manager:
            config += '  import "packagemanager_' + manager.get_id() + '"\n'

        config += Checkable.get_config(self)
        config += ValueMapper.parse_var('address', self.__ipv4)
        config += ValueMapper.parse_var('address6', self.__ipv6)
        config += ValueMapper.parse_var('vars.checks', self.__checks, value_prefix='check_')
        config += ValueMapper.parse_var('groups', self.__groups, value_prefix='hostgroup_')
        config += PluginDirs.get_config(self)
        config += ScriptDirs.get_config(self)
        config += CustomVars.get_config(self)

        config += '  check_command = "hostalive"\n'
        config += '  zone = "' + self.__execution_zone.get_id() + '"\n'
        config += ValueMapper.parse_var('vars.endpoint_name', self.__execution_endpoint)
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.Group import Group
from icinga2confgen.Notification.NotificationFunctions import NotificationFunctions
from icinga2confgen.ValueChecker import ValueChecker


class UserGroup(Group, NotificationFunctions):

    def __init__(self, id):
        Group.__init__(self, id, 'user')
        NotificationFunctions.__init__(self)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        usergroup = None if force_create else ConfigBuilder.get_usergroup(id)
        if None is usergroup:
            usergroup = UserGroup(id)
            ConfigBuilder.add_usergroup(id, usergroup)

        return usergroup

    def get_custom_config(self):
        return NotificationFunctions.get_config(self)

    def get_config(self):
        config = Group.get_config(self)
        config += 'object User "user_group_notification_sender_' + self.get_id() + '" {\n'
        config += '  display_name = "Notification sender of group ' + self.get_display_name() + '"'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.DigCommand import DigCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDig(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDig', 'dig')
        self.__warning_time = 5
        self.__critical_time = 10
        self.__dnsserver_hostname = '1.1.1.1'
        self.__dnsserver_port = None
        self.__only_ipv4 = False
        self.__only_ipv6 = False
        self.__question = None
        self.__timeout = 10
        self.__record_type = 'A'
        self.__expected_address = 'set expected address!'
        self.__question_arguments = None
        self.set_check_interval('15m')
        self.add_service_group(ServiceGroup.create('dns'))
        self.add_service_group(ServiceGroup.create('dig'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_warning_time(self, seconds):
        ValueChecker.is_number(seconds)
        self.__warning_time = seconds
        return self

    def get_warning_time(self):
        return self.__warning_time

    def set_critical_time(self, seconds):
        ValueChecker.is_number(seconds)
        self.__critical_time = seconds
        return self

    def get_critical_time(self):
        return self.__critical_time

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_question_arguments(self, arguments):
        ValueChecker.is_string(arguments)
        self.__question_arguments = arguments
        return self

    def get_question_arguments(self):
        return self.__question_arguments

    def set_expected_address(self, address):
        ValueChecker.is_string(address)
        self.__expected_address = address
        return self

    def get_expected_address(self):
        return self.__expected_address

    def set_record_type(self, type):
        ValueChecker.is_string(type)
        self.__record_type = type
        return self

    def get_record_type(self):
        return self.__record_type

    def set_question(self, address):
        ValueChecker.is_string(address)
        self.__question = address
        return self

    def get_question(self):
        return self.__question

    def set_dnsserver_hostname(self, hostname):
        ValueChecker.is_string(hostname)
        self.__dnsserver_hostname = hostname
        return self

    def get_dnsserver_hostname(self):
        return self.__dnsserver_hostname

    def set_dnsserver_port(self, port):
        ValueChecker.is_number(port)
        self.__dnsserver_port = port
        return self

    def get_dnsserver_port(self):
        return self.__dnsserver_port

    def set_only_ipv4(self, enabled):
        ValueChecker.is_number(enabled)
        self.__only_ipv4 = enabled
        return self

    def get_only_ipv4(self):
        return self.__only_ipv4

    def set_only_ipv6(self, enabled):
        ValueChecker.is_number(enabled)
        self.__only_ipv6 = enabled
        return self

    def get_only_ipv6(self):
        return self.__only_ipv6

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDig(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('dig'):
            DigCommand.create('dig')

        return check

    def validate(self):
        if None is self.__question:
            raise Exception('You have to specify a question for ' + self.get_id())
        if None is self.__record_type:
            raise Exception('You have to specify a record type for ' + self.get_id())
        if None is self.__expected_address:
            raise Exception('You have to specify an expected address for ' + self.get_id())
        if None is self.__warning_time:
            raise Exception('You have to specify a warning time for ' + self.get_id())
        if None is self.__critical_time:
            raise Exception('You have to specify a critical time for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.MonitoringPlugins.CheckDenyTlsVersion import CheckDenyTlsVersion
from icinga2confgen.Checks.NagiosPlugins.CheckDummy import CheckDummy
from icinga2confgen.Checks.NagiosPlugins.CheckHttp import CheckHttp
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Dependency.CheckDependency import CheckDependency
from icinga2confgen.Groups.HostGroup import HostGroup
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class DefaultWebserverChecks:

    def __init__(self, vhostconfig=[], servers=[], checkserver=[], notifications=[]):
        self.__checkserver = checkserver
        self.__notifications = notifications
        self.__servers = servers
        self.__vhostconfigs = vhostconfig
        self.__validate_certificate = True
        self.__validate_http_redirect = True
        self.__warn_no_http_redirect = True
        self.__validate_allow_tls1 = False
        self.__validate_deny_tls1 = True
        self.__validate_allow_tls1_1 = False
        self.__validate_deny_tls1_1 = True
        self.__validate_allow_tls1_2 = True
        self.__validate_deny_tls1_2 = False
        self.__validate_allow_tls1_3 = True
        self.__validate_deny_tls1_3 = False
        self.__sni = True

    def get_vhostconfigs(self):
        return self.__vhostconfigs

    def get_servers(self):
        return self.__servers

    def get_notifications(self):
        return self.__notifications

    def get_checkservers(self):
        return self.__checkserver

    def validate_certificate(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_certificate = enabled

        return self

    def is_validating_certificate(self):
        return self.__validate_certificate

    def validate_http_redirect(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_http_redirect = enabled

        return self

    def is_validating_http_redirect(self):
        return self.__validate_http_redirect

    def warn_no_http_redirect(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__warn_no_http_redirect = enabled

        return self

    def is_warn_no_http_redirect(self):
        return self.__warn_no_http_redirect

    def validate_allow_tls1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1 = enabled

        return self

    def is_validating_allow_tls1(self):
        return self.__validate_allow_tls1

    def validate_deny_tls1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1 = enabled

        return self

    def is_validating_deny_tls1(self):
        ValueChecker.is_bool(enabled)
        return self.__validate_deny_tls1

    def validate_allow_tls1_1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1_1 = enabled

        return self

    def is_validating_allow_tls1_1(self):
        return self.__validate_allow_tls1_1

    def validate_deny_tls1_1(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1_1 = enabled

        return self

    def is_validating_deny_tls1_1(self):
        return self.__validate_deny_tls1_1

    def validate_allow_tls1_2(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1_2 = enabled

        return self

    def is_validating_allow_tls1_2(self):
        return self.__validate_allow_tls1_2

    def validate_deny_tls1_2(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1_2 = enabled

        return self

    def is_validating_deny_tls1_2(self):
        return self.__validate_deny_tls1_2

    def validate_allow_tls1_3(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_allow_tls1_3 = enabled

        return self

    def is_validating_allow_tls1_3(self):
        return self.__validate_allow_tls1_3

    def validate_deny_tls1_3(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_tls1_3 = enabled

        return self

    def is_validating_deny_tls1_3(self):
        return self.__validate_deny_tls1_3

    def set_sni(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__sni = enabled

        return self

    def get_sni(self):
        return self.__sni

    def apply_notification_to_check(self, check):
        for notification in self.__notifications:
            check.add_notification(notification)

    def apply_check_to_checkserver(self, check, depends_on=None):

        self.apply_notification_to_check(check)
        for checkserver in self.__checkserver:
            checkserver.add_check(check)
            if None != depends_on:
                dependency = CheckDependency.create(
                    check.get_id() + '_require_' + depends_on.get_id() + '_on_' + checkserver.get_id()) \
                    .set_server(checkserver) \
                    .set_check(depends_on)
                check.add_dependency(dependency)

    def get_default_access_check(self, service_baseid, server, domain):
        base_id = service_baseid + '_' + server.get_id() + '_' + ValueMapper.canonicalize_for_id(domain)
        return {
            'ipv4': ConfigBuilder.get_check('web_access_default_ipv4_' + base_id),
            'ipv6': ConfigBuilder.get_check('web_access_default_ipv6_' + base_id)
        }

    def apply(self):
        for config in self.__vhostconfigs:
            service_baseid = config[0]
            domain = config[1]
            uri = config[2]

            for server in self.__servers:
                base_id = service_baseid + '_' + server.get_id() + '_' + ValueMapper.canonicalize_for_id(domain)
                server_ipv4 = server.get_ipv4()
                server_ipv6 = server.get_ipv6()

                if None is server_ipv4 and None is server_ipv6:
                    raise Exception('It is required to set the ipv4 or ipv6 on the server with id "' +
                                    server.get_id() + '", before you can apply this checks!')

                server.add_hostgroup(HostGroup.create('webserver'))

                default_ipv4_http_check = None
                default_ipv6_http_check = None
                if None is not server_ipv4:
                    default_ipv4_http_check = CheckHttp.create('web_access_default_ipv4_' + base_id)
                    default_ipv4_http_check.set_ip(server_ipv4) \
                        .set_vhost(domain) \
                        .set_uri(uri) \
                        .set_ssl(True) \
                        .set_sni(self.__sni) \
                        .set_display_name(default_ipv4_http_check.get_display_name() + ' ' + domain)
                    self.apply_check_to_checkserver(default_ipv4_http_check)

                if None is not server_ipv6:
                    default_ipv6_http_check = CheckHttp.create('web_access_default_ipv6_' + base_id)
                    default_ipv6_http_check.set_ip(server_ipv6) \
                        .set_vhost(domain) \
                        .set_uri(uri) \
                        .set_ssl(True) \
                        .set_sni(self.__sni) \
                        .set_display_name(default_ipv6_http_check.get_display_name() + ' ' + domain)
                    self.apply_check_to_checkserver(default_ipv6_http_check)

                if None == default_ipv4_http_check and None == default_ipv6_http_check:
                    raise Exception('Server "' + server.get_id()
                                    + '" has no IPv4 and no IPv6 address set. Can\'t go further right now.')

                if True is self.__validate_certificate:
                    if None is not server_ipv4:
                        certificate_check = CheckHttp.create('web_access_certificate_ipv4_' + base_id)
                        certificate_check.set_ip(server_ipv4) \
                            .set_vhost(domain) \
                            .set_uri(uri) \
                            .set_ssl(True) \
                            .set_sni(self.__sni) \
                            .set_certificate_check(True) \
                            .set_check_interval('3h') \
                            .add_service_group(ServiceGroup.create('certificate_check')) \
                            .set_display_name(certificate_check.get_display_name() + ' ' + domain)

                        self.apply_check_to_checkserver(certificate_check, default_ipv4_http_check)

                    if None is not server_ipv6:
                        certificate_check = CheckHttp.create('web_access_certificate_ipv6_' + base_id)
                        certificate_check.set_ip(server_ipv6) \
                            .set_vhost(domain) \
                            .set_uri(uri) \
                            .set_ssl(True) \
                            .set_sni(self.__sni) \
                            .set_certificate_check(True) \
                            .set_check_interval('3h') \
                            .add_service_group(ServiceGroup.create('certificate_check')) \
                            .set_display_name(certificate_check.get_display_name() + ' ' + domain)

                        self.apply_check_to_checkserver(certificate_check, default_ipv6_http_check)

                else:
                    server.add_hostgroup(HostGroup.create('no_certificate_check'))

                if True is self.__validate_http_redirect:
                    if None is not server_ipv4:
                        redirect_check = CheckHttp.create('web_access_http_redirect_ipv4_' + base_id)
                        redirect_check.set_ip(server_ipv4) \
                            .set_vhost(domain) \
                            .set_uri(uri) \
                            .set_ssl(False) \
                            .set_sni(self.__sni) \
                            .set_port(80) \
                            .set_expect('HTTP/1.1 30') \
                            .set_check_interval('6h') \
                            .add_service_group(ServiceGroup.create('http_redirect')) \
                            .set_display_name(redirect_check.get_display_name() + ' ' + domain)

                        self.apply_check_to_checkserver(redirect_check, default_ipv4_http_check)

                    if None is not server_ipv6:
                        redirect_check = CheckHttp.create('web_access_http_redirect_ipv6_' + base_id)
                        redirect_check.set_ip(server_ipv6) \
                            .set_vhost(domain) \
                            .set_uri(uri) \
                            .set_ssl(False) \
                            .set_sni(self.__sni) \
                            .set_port(80) \
                            .set_expect('HTTP/1.1 30') \
                            .set_check_interval('6h') \
                            .add_service_group(ServiceGroup.create('http_redirect')) \
                            .set_display_name(redirect_check.get_display_name() + ' ' + domain)

                        self.apply_check_to_checkserver(redirect_check, default_ipv6_http_check)

                    server.add_hostgroup(HostGroup.create('http_redirect'))

                elif True is self.__warn_no_http_redirect:
                    redirect_check = CheckDummy.create('web_access_missing_http_redirect_' + base_id)
                    redirect_check.set_state(1) \
                        .set_text(redirect_check.get_display_name() + ' ' + domain) \
                        .set_check_interval('6h') \
                        .add_service_group(ServiceGroup.create('missing_http_redirect_check')) \
                        .add_service_group(ServiceGroup.create('webserver')) \
                        .set_display_name(redirect_check.get_display_name() + ' ' + domain)

                    self.apply_check_to_checkserver(redirect_check)
                    server.add_hostgroup(HostGroup.create('no_http_redirect'))

                else:
                    server.add_hostgroup(HostGroup.create('http_redirect_unchecked'))

                self.add_tls_check(base_id, default_ipv4_http_check, default_ipv6_http_check, domain,
                                   server, server_ipv4, server_ipv6, uri, '1.0', self.__validate_allow_tls1,
                                   self.__validate_deny_tls1, True)

                self.add_tls_check(base_id, default_ipv4_http_check, default_ipv6_http_check, domain,
                                   server, server_ipv4, server_ipv6, uri, '1.1', self.__validate_allow_tls1_1,
                                   self.__validate_deny_tls1_1, True)

                self.add_tls_check(base_id, default_ipv4_http_check, default_ipv6_http_check, domain,
                                   server, server_ipv4, server_ipv6, uri, '1.2', self.__validate_allow_tls1_2,
                                   self.__validate_deny_tls1_2, False)

                self.add_tls_check(base_id, default_ipv4_http_check, default_ipv6_http_check, domain,
                                   server, server_ipv4, server_ipv6, uri, '1.3', self.__validate_allow_tls1_3,
                                   self.__validate_deny_tls1_3, False)

    def add_tls_check(self, base_id, default_ipv4_http_check, default_ipv6_http_check, domain, server,
                      server_ipv4, server_ipv6, uri, protocol, allow, deny, insecure):
        protocol_id = protocol.replace('.', '_')

        if insecure:
            server.add_hostgroup(HostGroup.create('insecure_webserver'))
        else:
            server.add_hostgroup(HostGroup.create('secure_webserver'))

        if allow:
            if None is not server_ipv4:
                tls_check = CheckHttp.create('web_access_allow_tls' + protocol_id + '_ipv4_' + base_id)
                tls_check.set_ip(server_ipv4) \
                    .set_vhost(domain) \
                    .set_uri(uri) \
                    .set_sni(self.__sni) \
                    .set_ssl_protocol(protocol) \
                    .set_check_interval('6h') \
                    .add_service_group(ServiceGroup.create('tls_' + protocol_id + '_check')) \
                    .add_service_group(ServiceGroup.create('tls')) \
                    .set_display_name(tls_check.get_display_name() + ' ' + domain)

                self.apply_check_to_checkserver(tls_check, default_ipv4_http_check)

            if None is not server_ipv6:
                tls_check = CheckHttp.create('web_access_allow_tls' + protocol_id + '_ipv6_' + base_id)
                tls_check.set_ip(server_ipv6) \
                    .set_vhost(domain) \
                    .set_uri(uri) \
                    .set_sni(self.__sni) \
                    .set_ssl_protocol(protocol) \
                    .set_check_interval('6h') \
                    .add_service_group(ServiceGroup.create('tls_' + protocol_id + '_check')) \
                    .add_service_group(ServiceGroup.create('tls')) \
                    .set_display_name(tls_check.get_display_name() + ' ' + domain)

                self.apply_check_to_checkserver(tls_check, default_ipv6_http_check)

            if insecure:
                server.add_hostgroup(HostGroup.create('insecure_webserver'))
                server.add_hostgroup(HostGroup.create('insecure_TLSv' + protocol_id + '_Webserver'))
            else:
                server.add_hostgroup(HostGroup.create('secure_webserver'))
                server.add_hostgroup(HostGroup.create('secure_TLSv' + protocol_id + '_Webserver'))

        elif deny:
            if None is not server_ipv4:
                tls_check = CheckDenyTlsVersion.create('web_access_deny_tls' + protocol_id + '_ipv4_' + base_id)
                tls_check.set_address(server_ipv4) \
                    .set_domain(domain) \
                    .set_protocol(protocol) \
                    .set_check_interval('6h') \
                    .add_service_group(ServiceGroup.create('tls_' + protocol_id + '_check')) \
                    .set_display_name(tls_check.get_display_name() + ' ' + domain)

                self.apply_check_to_checkserver(tls_check, default_ipv4_http_check)

            if None is not server_ipv6:
                tls_check = CheckDenyTlsVersion.create('web_access_deny_tls' + protocol_id + '_ipv6_' + base_id)
                tls_check.set_address(server_ipv6) \
                    .set_domain(domain) \
                    .set_protocol(protocol) \
                    .set_check_interval('6h') \
                    .add_service_group(ServiceGroup.create('tls_' + protocol_id + '_check')) \
                    .set_display_name(tls_check.get_display_name() + ' ' + domain)
                self.apply_check_to_checkserver(tls_check, default_ipv6_http_check)

            server.add_hostgroup(HostGroup.create('deny_insecure_TLSv' + protocol_id + '_webserver'))

            if insecure:
                server.add_hostgroup(HostGroup.create('deny_insecure_TLSv' + protocol_id + '_Webserver'))
            else:
                server.add_hostgroup(HostGroup.create('deny_secure_TLSv' + protocol_id + '_Webserver'))
        else:
            server.add_hostgroup(HostGroup.create('deny_insecure_TLSv' + protocol_id + '_unchecked'))



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.HariSekhonNagiosPlugins.CheckYum import CheckYum
from icinga2confgen.Checks.MonitoringPlugins.CheckExistingUsers import CheckExistingUsers
from icinga2confgen.Checks.MonitoringPlugins.CheckGroupMembers import CheckGroupMembers
from icinga2confgen.Checks.MonitoringPlugins.CheckSSHDSecurity import CheckSSHDSecurity
from icinga2confgen.Checks.MonitoringPlugins.CheckUFWStatus import CheckUFWStatus
from icinga2confgen.Checks.NagiosPlugins.CheckApt import CheckApt
from icinga2confgen.Checks.NagiosPlugins.CheckDisk import CheckDisk
from icinga2confgen.Checks.NagiosPlugins.CheckLoad import CheckLoad
from icinga2confgen.Checks.NagiosPlugins.CheckNTPTime import CheckNTPTime
from icinga2confgen.Checks.NagiosPlugins.CheckProcs import CheckProcs
from icinga2confgen.Checks.NagiosPlugins.CheckSWAP import CheckSWAP
from icinga2confgen.Checks.NagiosPlugins.CheckUsers import CheckUsers
from icinga2confgen.Dependency.CheckDependency import CheckDependency
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class DefaultLocalChecks:

    def __init__(self, servers=[], notifications=[], sudoers=[], additional_users=[]):
        self.__additional_users = additional_users
        self.__servers = servers
        self.__notifications = notifications
        self.__check_type = 'local'
        self.__check_load = True
        self.__check_apt = True
        self.__check_yum = False
        self.__check_users = True
        self.__check_swap = True
        self.__check_ntp_time = True
        self.__check_disk = True
        self.__check_sshd_security = True
        self.__check_sshd_running = True
        self.__check_mysqld_running = False
        self.__check_postgres_running = False
        self.__check_cron_running = True
        self.__check_crond_running = False
        self.__check_rsyslogd_running = True
        self.__check_nginx_running = False
        self.__check_apache_running = False
        self.__check_httpd_running = False
        self.__check_tomcat_running = False
        self.__check_php_fpm_running = False
        self.__check_freshclam_running = False
        self.__check_clamd_running = False
        self.__check_postfix_running = False
        self.__check_sudoers = True
        self.__check_normal_users = True
        self.__check_wheel = False
        self.__check_ufw = True
        self.__sudoers = sudoers
        self.__check_partitions = []
        self.__ufw_rules = []
        self.__ufw_defaults = ('deny', 'allow', 'deny')

    def check_load(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_load = enabled

        return self

    def is_checking_load(self):
        return self.__check_load

    def check_apt(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_apt = enabled

        return self

    def is_checking_apt(self):
        return self.__check_apt

    def check_yum(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_yum = enabled

        return self

    def is_checking_yum(self):
        return self.__check_yum

    def check_users(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_users = enabled

        return self

    def is_checking_users(self):
        return self.__check_users

    def check_swap(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_swap = enabled

        return self

    def is_checking_swap(self):
        return self.__check_swap

    def check_ntp_time(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_ntp_time = enabled

        return self

    def is_checking_ntp_time(self):
        return self.__check_ntp_time

    def check_disk(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_disk = enabled

        return self

    def is_checking_disk(self):
        return self.__check_disk

    def check_sshd_security(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_sshd_security = enabled

        return self

    def is_checking_sshd_security(self):
        return self.__check_sshd_security

    def check_sshd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_sshd_running = enabled

        return self

    def is_checking_sshd_running(self):
        return self.__check_sshd_running

    def check_freshclam_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_freshclam_running = enabled

        return self

    def is_checking_freshclam_running(self):
        return self.__check_freshclam_running

    def check_clamd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_clamd_running = enabled

        return self

    def is_checking_clamd_running(self):
        return self.__check_clamd_running

    def check_postfix_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_postfix_running = enabled

        return self

    def is_checking_postfix_running(self):
        return self.__check_postfix_running

    def check_mysqld_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_mysqld_running = enabled

        return self

    def is_checking_mysqld_running(self):
        return self.__check_mysqld_running

    def check_postgres_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_postgres_running = enabled

        return self

    def is_checking_postgres_running(self):
        return self.__check_postgres_running

    def check_cron_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_cron_running = enabled

        return self

    def is_checking_cron_running(self):
        return self.__check_cron_running

    def check_crond_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_crond_running = enabled

        return self

    def is_checking_crond_running(self):
        return self.__check_crond_running

    def check_rsyslogd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_rsyslogd_running = enabled

        return self

    def is_checking_rsyslogd_running(self):
        return self.__check_rsyslogd_running

    def check_nginx_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_nginx_running = enabled

        return self

    def is_checking_nginx_running(self):
        return self.__check_nginx_running

    def check_apache_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_apache_running = enabled

        return self

    def is_checking_apache_running(self):
        return self.__check_apache_running

    def check_httpd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_httpd_running = enabled

        return self

    def is_checking_httpd_running(self):
        return self.__check_httpd_running

    def check_tomcat_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_tomcat_running = enabled

        return self

    def is_checking_tomcat_running(self):
        return self.__check_tomcat_running

    def check_php_fpm_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_php_fpm_running = enabled

        return self

    def is_checking_php_fpm_running(self):
        return self.__check_php_fpm_running

    def check_ufw(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_ufw = enabled

        return self

    def is_checking_ufw(self):
        return self.__check_ufw

    def add_ufw_rule(self, policy_from, policy_to, policy_action):
        ValueChecker.is_string(policy_from)
        ValueChecker.is_string(policy_to)
        ValueChecker.is_string(policy_action)
        self.__ufw_rules.append(
            (policy_from.replace(' ', '-'), policy_to.replace(' ', '-'), policy_action.replace(' ', '-')))
        return self

    def set_ufw_defaults(self, incoming, outgoing, routing):
        self.__ufw_defaults = tuple((incoming, outgoing, routing))
        return self

    def add_server(self, server):
        self.__servers.append(server)
        return self

    def get_server(self):
        return self.__servers

    def add_partition(self, id, path, warning_percent, critical_percent):
        ValueChecker.is_string(id)
        ValueChecker.is_string(path)
        ValueChecker.is_number(warning_percent)
        ValueChecker.is_number(critical_percent)
        self.__check_partitions.append((id, path, warning_percent, critical_percent))

        return self

    def check_sudoers(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_sudoers = enabled

        return self

    def is_checking_sudoers(self):
        return self.__check_sudoers

    def check_normal_users(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_normal_users = enabled

        return self

    def is_checking_normal_users(self):
        return self.__check_normal_users

    def check_wheel(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_wheel = enabled

        return self

    def is_checking_wheel(self):
        return self.__check_wheel

    def add_sudoers(self, username):
        ValueChecker.is_string(username)
        self.__sudoers.append(username)

        return self

    def add_normal_user(self, username):
        ValueChecker.is_string(username)
        self.__additional_users.append(username)

        return self

    def add_notification(self, notification):
        # todo type check
        self.__notifications.append(notification)
        return self

    def get_notification(self):
        return self.__notifications

    def apply_notification_to_check(self, check):
        # todo type check
        for notification in self.__notifications:
            check.add_notification(notification)
        return self

    def set_check_type(self, type):
        # todo type check
        self.__check_type = type
        return self

    def create_running_check(self, name, command, server):
        check = CheckProcs.create('running_proc_' + name + '_' + server.get_id()) \
            .set_check_type(self.__check_type) \
            .set_critical_range('1:') \
            .set_command(command) \
            .add_service_group(ServiceGroup.create(name))
        self.apply_notification_to_check(check)
        server.add_check(check)

        return check

    def create_running_check_arguments(self, name, argument, server):
        check = CheckProcs.create('running_proc_' + name + '_' + server.get_id()) \
            .set_check_type(self.__check_type) \
            .set_critical_range('1:') \
            .set_argument(argument) \
            .add_service_group(ServiceGroup.create(name))
        self.apply_notification_to_check(check)
        server.add_check(check)

        return check

    def apply(self):
        for server in self.__servers:
            if True is self.__check_apt:
                check = CheckApt.create('apt_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_yum:
                check = CheckYum.create('yum_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_load:
                check = CheckLoad.create('load_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_ntp_time:
                check = CheckNTPTime.create('ntp_time_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_swap:
                check = CheckSWAP.create('swap_' + server.get_id()) \
                    .set_check_type(self.__check_type)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_users:
                check = CheckUsers.create('users_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            sshd_running_check = None
            if True is self.__check_sshd_running:
                sshd_running_check = self.create_running_check('sshd', 'sshd', server)

            if True is self.__check_sshd_security:
                check = CheckSSHDSecurity.create('sshd_security_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

                if None != sshd_running_check:
                    dependency = CheckDependency.create('sshd_security_require_sshd_running_' + server.get_id()) \
                        .set_server(server) \
                        .set_check(sshd_running_check)
                    check.add_dependency(dependency)

            if True is self.__check_mysqld_running:
                check = self.create_running_check('mysql', 'mysqld', server)
                check.add_service_group(ServiceGroup.create('database'))

            if True is self.__check_postgres_running:
                check = self.create_running_check('postgres', 'postgres', server)
                check.add_service_group(ServiceGroup.create('database'))

            if True is self.__check_cron_running:
                self.create_running_check('cron', 'cron', server)

            if True is self.__check_crond_running:
                self.create_running_check('cron', 'crond', server)

            if True is self.__check_rsyslogd_running:
                self.create_running_check('rsyslogd', 'rsyslogd', server)

            if True is self.__check_nginx_running:
                check = self.create_running_check('nginx', 'nginx', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_apache_running:
                check = self.create_running_check('apache', 'apache2', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_httpd_running:
                check = self.create_running_check('httpd', 'httpd', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_tomcat_running:
                check = self.create_running_check('tomcat', 'tomcat', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_php_fpm_running:
                self.create_running_check('php_fpm', 'php-fpm', server)

            if True is self.__check_freshclam_running:
                check = self.create_running_check('freshclam', 'freshclam', server)
                check.add_service_group(ServiceGroup.create('security'))
                check.add_service_group(ServiceGroup.create('antivirus'))

            if True is self.__check_clamd_running:
                check = self.create_running_check('clamd', 'clamd', server)
                check.add_service_group(ServiceGroup.create('security'))
                check.add_service_group(ServiceGroup.create('antivirus'))

            if True is DefaultLocalChecks.is_checking_postfix_running(self):
                check = self.create_running_check_arguments('postfix', 'postfix', server)
                check.add_service_group(ServiceGroup.create('mail'))

            if True is self.__check_sudoers:
                check = CheckGroupMembers.create('sudoers_group_members_' + server.get_id()) \
                    .set_check_type(self.__check_type) \
                    .add_service_group(ServiceGroup.create('sudoers'))
                for user in self.__sudoers:
                    check.append_user(user)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_wheel:
                check = CheckGroupMembers.create('wheel_group_members_' + server.get_id()) \
                    .set_group('wheel') \
                    .set_check_type(self.__check_type) \
                    .add_service_group(ServiceGroup.create('sudoers'))
                for user in self.__sudoers:
                    check.append_user(user)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_normal_users:
                check = CheckExistingUsers.create('existing_users_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                for user in self.__sudoers:
                    check.append_existing_users(user)
                for user in self.__additional_users:
                    check.append_existing_users(user)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_ufw:
                check = CheckUFWStatus.create('ufw_status_' + server.get_id()) \
                    .set_incoming(self.__ufw_defaults[0]) \
                    .set_outgoing(self.__ufw_defaults[1]) \
                    .set_routing(self.__ufw_defaults[2]) \
                    .set_check_type(self.__check_type)
                for policy in self.__ufw_rules:
                    check.add_rule(policy[0], policy[1], policy[2])

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_disk:
                if len(self.__check_partitions) == 0:
                    check = CheckDisk.create('disk_' + server.get_id()) \
                        .set_check_type(self.__check_type)
                    self.apply_notification_to_check(check)
                    server.add_check(check)
                else:
                    for config in self.__check_partitions:
                        check = CheckDisk.create('disk_' + config[0] + '_' + server.get_id())
                        check.set_display_name(check.get_display_name() + ' ' + config[0]) \
                            .set_check_type(self.__check_type) \
                            .set_partition(config[1]) \
                            .set_warning_percent(config[2]) \
                            .set_critical_percent(config[3])
                        self.apply_notification_to_check(check)
                        server.add_check(check)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.DiskCommand import DiskCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDisk(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDisk', 'disk')
        self.__warning = '20%'
        self.__critical = '10%'
        self.__inode_warning = 20
        self.__inode_critical = 10
        self.__combined_thresholds = None
        self.__path = None
        self.__partition = None
        self.__exclude_device = None
        self.__clear_thresholds = None
        self.__exact_match = None
        self.__errors_only = None
        self.__freespace_ignore_reserved = None
        self.__group = None
        self.__local = None
        self.__skip_fake_fs = None
        self.__inode_perfdata = None
        self.__stat_remote_fs = None
        self.__display_mountpoint = None
        self.__all = None
        self.__eregi_path = None
        self.__eregi_partition = None
        self.__ignore_eregi_path = None
        self.__ignore_eregi_partition = None
        self.__ereg_path = None
        self.__ereg_partition = None
        self.__ignore_ereg_path = None
        self.__ignore_ereg_partition = None
        self.__timeout = None
        self.__units = None
        self.__exclude_type = None
        self.__include_type = None
        self.__newlines = None
        self.set_check_interval('30m')
        self.add_service_group(ServiceGroup.create('disk'))

    def set_warning_units(self, number):
        ValueChecker.is_number(number)
        self.__warning = str(number)
        return self

    def get_warning_units(self):
        return self.__warning

    def set_warning_percent(self, number):
        ValueChecker.is_number(number)
        self.__warning = str(number) + '%'
        return self

    def get_warning_percent(self):
        return self.__warning

    def set_critical_units(self, number):
        ValueChecker.is_number(number)
        self.__critical = str(number)
        return self

    def get_critical_units(self):
        return self.__critical

    def set_critical_percent(self, number):
        ValueChecker.is_number(number)
        self.__critical = str(number) + '%'
        return self

    def get_critical_percent(self):
        return self.__critical

    def set_warning_inode_percent(self, number):
        ValueChecker.is_number(number)
        self.__inode_warning = number
        return self

    def get_warning_inode_percent(self):
        return self.__inode_warning

    def set_critical_inode_percent(self, number):
        ValueChecker.is_number(number)
        self.__inode_critical = number
        return self

    def get_critical_inode_percent(self):
        return self.__inode_critical

    def set_timeout(self, number):
        ValueChecker.is_number(number)
        self.__timeout = number
        return self

    def get_timeout(self):
        return self.__timeout

    def set_newlines(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__newlines = enabled
        return self

    def get_newlines(self):
        return self.__newlines

    def set_combined_thresholds(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__combined_thresholds = enabled
        return self

    def get_combined_thresholds(self):
        return self.__combined_thresholds

    def set_clear_thresholds(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__clear_thresholds = enabled
        return self

    def get_clear_thresholds(self):
        return self.__clear_thresholds

    def set_freespace_ignore_reserved(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__freespace_ignore_reserved = enabled
        return self

    def get_freespace_ignore_reserved(self):
        return self.__freespace_ignore_reserved

    def set_errors_only(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__errors_only = enabled
        return self

    def get_errors_only(self):
        return self.__errors_only

    def set_local(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__local = enabled
        return self

    def get_local(self):
        return self.__local

    def set_all(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__all = enabled
        return self

    def get_all(self):
        return self.__all

    def set_display_mountpoint(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__display_mountpoint = enabled
        return self

    def get_display_mountpoint(self):
        return self.__display_mountpoint

    def set_stat_remote_fs(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__stat_remote_fs = enabled
        return self

    def get_stat_remote_fs(self):
        return self.__stat_remote_fs

    def set_inode_perfdata(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__inode_perfdata = enabled
        return self

    def get_inode_perfdata(self):
        return self.__inode_perfdata

    def set_skip_fake_fs(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__skip_fake_fs = enabled
        return self

    def get_skip_fake_fs(self):
        return self.__skip_fake_fs

    def set_path(self, path):
        ValueChecker.is_string(path)
        if None is self.__path:
            self.__path = []

        self.__path.append(path)
        return self

    def get_path(self):
        return self.__path

    def set_exclude_device(self, exclude_device):
        ValueChecker.is_string(exclude_device)
        self.__exclude_device = exclude_device
        return self

    def get_exclude_device(self):
        return self.__exclude_device

    def set_partition(self, partition):
        ValueChecker.is_string(partition)
        self.__partition = partition
        return self

    def get_partition(self):
        return self.__partition

    def set_group(self, group):
        ValueChecker.is_string(group)
        self.__group = group
        return self

    def get_group(self):
        return self.__group

    def set_units(self, units):
        ValueChecker.is_string(units)
        self.__units = units
        return self

    def get_units(self):
        return self.__units

    def set_include_type(self, include_type):
        ValueChecker.is_string(include_type)
        if None is self.__include_type:
            self.__include_type = []

        self.__include_type.append(include_type)
        return self

    def get_include_type(self):
        return self.__include_type

    def set_exclude_type(self, exclude_type):
        ValueChecker.is_string(exclude_type)
        if None is self.__exclude_type:
            self.__exclude_type = []

        self.__exclude_type.append(exclude_type)
        return self

    def get_exclude_type(self):
        return self.__exclude_type

    def set_eregi_path(self, eregi_path):
        ValueChecker.is_string(eregi_path)
        if None is self.__eregi_path:
            self.__eregi_path = []
        self.__eregi_path.append(eregi_path)
        return self

    def get_eregi_path(self):
        return self.__eregi_path

    def set_eregi_partition(self, eregi_partition):
        ValueChecker.is_string(eregi_partition)
        self.__eregi_partition = eregi_partition
        return self

    def get_eregi_partition(self):
        return self.__eregi_partition

    def set_ereg_path(self, ereg_path):
        ValueChecker.is_string(ereg_path)
        if None is self.__ereg_path:
            self.__ereg_path = []

        self.__ereg_path.append(ereg_path)
        return self

    def get_ereg_path(self):
        return self.__ereg_path

    def set_ereg_partition(self, ereg_partition):
        ValueChecker.is_string(ereg_partition)
        self.__ereg_partition = ereg_partition
        return self

    def get_ereg_partition(self):
        return self.__ereg_partition

    def set_ignore_eregi_path(self, ignore_eregi_path):
        ValueChecker.is_string(ignore_eregi_path)
        if None is self.__ignore_ereg_path:
            self.__ignore_eregi_path = []
        self.__ignore_eregi_path.append(ignore_eregi_path)
        return self

    def get_ignore_eregi_path(self):
        return self.__ignore_eregi_path

    def set_ignore_eregi_partition(self, ignore_eregi_partition):
        ValueChecker.is_string(ignore_eregi_partition)
        self.__ignore_eregi_partition = ignore_eregi_partition
        return self

    def get_ignore_eregi_partition(self):
        return self.__ignore_eregi_partition

    def set_ignore_ereg_path(self, ignore_ereg_path):
        ValueChecker.is_string(ignore_ereg_path)
        if None is self.__ignore_ereg_path:
            self.__ignore_ereg_path = []

        self.__ignore_ereg_path.append(ignore_ereg_path)
        return self

    def get_ignore_ereg_path(self):
        return self.__ignore_ereg_path

    def set_ignore_ereg_partition(self, ignore_ereg_partition):
        ValueChecker.is_string(ignore_ereg_partition)
        self.__ignore_ereg_partition = ignore_ereg_partition
        return self

    def get_ignore_ereg_partition(self):
        return self.__ignore_ereg_partition

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDisk(id) \
                .set_check_interval('15m') \
                .add_service_group(ServiceGroup.create('disk').set_display_name('Disk'))
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('disk'):
            DiskCommand.create('disk')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.DockerLoginCommand import DockerLoginCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDockerLogin(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDockerLogin', 'docker_login')
        self.__user = None
        self.__credentials = None
        self.__address = None
        self.__port = None
        self.__as_sudo = False
        self.add_service_group(ServiceGroup.create('docker'))

    def set_as_sudo(self, as_sudo):
        ValueChecker.is_bool(as_sudo)
        self.__as_sudo = as_sudo
        return self

    def get_as_sudo(self):
        return self.__as_sudo

    def set_user(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user(self):
        return self.__user

    def set_credentials(self, credentials):
        ValueChecker.is_string(credentials)
        self.__credentials = credentials
        return self

    def get_credentials(self):
        return self.__credentials

    def set_port(self, port):
        ValueChecker.is_string(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_address(self, address):
        ValueChecker.is_string(address)
        self.__address = address
        return self

    def get_address(self):
        return self.__address

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDockerLogin(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('docker_login'):
            DockerLoginCommand.create('docker_login')

        return check

    def validate(self):
        if None is self.__user:
            raise Exception('You have to specify a user for ' + self.get_id())
        if None is self.__credentials:
            raise Exception('You have to specify credentials for ' + self.get_id())
        if None is self.__port:
            raise Exception('You have to specify a port for ' + self.get_id())
        if None is self.__address:
            raise Exception('You have to specify an address for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Notification.NotificationCommand import NotificationCommand
from icinga2confgen.ValueChecker import ValueChecker


class MailNotificationCommand(NotificationCommand):

    def __init__(self, id):
        NotificationCommand.__init__(self, id)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_notification_command(id)
        if None is command:
            command = MailNotificationCommand(id)
            ConfigBuilder.add_notification_command(id, command)

        return command

    def get_command_executable_host(self):
        return 'mail-host-notification.sh'

    def get_command_executable_service(self):
        return 'mail-service-notification.sh'

    def get_script_dir(self):
        return "$icinga_script_dir$"

    def validate(self):
        pass

    def get_arguments_host(self):
        config = '{\n' + self.get_default_arguments_host() + """
   "-r" = {
      value = "$notification_email$"
      required = true
    }       
}"""
        config += self.get_default_vars_host()

        return config

    def get_arguments_service(self):
        config = '{\n' + self.get_default_arguments_service() + """
   "-r" = {
      value = "$notification_email$"
      required = true
    }       
}"""
        config += self.get_default_vars_service()

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.SSHCommand import SSHCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSSH(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSSH', 'ssh')
        self.__hostname = None
        self.__port = None
        self.__timeout = None
        self.__remote_version = None
        self.__remote_protocol = None
        self.__force_ipv4 = None
        self.__force_ipv6 = None
        self.add_service_group(ServiceGroup.create('sshd'))

    def set_hostname(self, hostname):
        ValueChecker.is_string(hostname)
        self.__hostname = hostname
        return self

    def get_hostname(self):
        return self.__hostname

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_remote_version(self, remote_version):
        ValueChecker.is_string(remote_version)
        self.__remote_version = remote_version
        return self

    def get_remote_version(self):
        return self.__remote_version

    def set_remote_protocol(self, remote_protocol):
        ValueChecker.is_string(remote_protocol)
        self.__remote_protocol = remote_protocol
        return self

    def get_remote_protocol(self):
        return self.__remote_protocol

    def set_force_ipv4(self, enabled):
        ValueChecker.is_number(enabled)
        self.__force_ipv4 = enabled
        return self

    def get_force_ipv4(self):
        return self.__force_ipv4

    def set_force_ipv6(self, enabled):
        ValueChecker.is_number(enabled)
        self.__force_ipv6 = enabled
        return self

    def get_force_ipv6(self):
        return self.__force_ipv6

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSSH(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ssh'):
            SSHCommand.create('ssh')

        return check

    def validate(self):
        if None is self.__hostname:
            raise Exception('You have to specify a hostname for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.Helpers import DefaultNames
from icinga2confgen.Helpers.Checkable import Checkable
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class Check(Checkable):

    def __init__(self, id, class_name, command_name):
        Checkable.__init__(self)
        self.__command_name = command_name
        self.__class_name = class_name
        self.__id = id
        self.__service_groups = []
        self.__check_type = "local"
        self.__allowed_check_types = ["local", "ssh"]
        self.set_display_name(DefaultNames.get_default_check_name(id, command_name))

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = Check(id, 'Check', 'check')
            ConfigBuilder.add_check(id, check)

        return check

    def validate(self):
        raise Exception('Each check must override validate method')

    def add_service_group(self, group):
        if isinstance(group, ServiceGroup):
            self.__service_groups.append(group.get_id())
        elif isinstance(group, str):
            if None is ConfigBuilder.get_servicegroup(group):
                raise Exception('ServiceGroup does not exist yet!')
            self.__service_groups.append('servicegroup_' + group)
        else:
            raise Exception('Can only add Servicegroup or id of Servicegroup!')

        return self

    def get_service_groups(self):

        return self.__service_groups

    def get_id(self):
        return self.__id

    def set_check_type(self, type):
        if type in self.__allowed_check_types:
            self.__check_type = type
            return self
        raise Exception("Checktype must be " + ' or '.join(self.__allowed_check_types))

    def get_check_type(self):
        return self.__check_type

    def get_custom_definitions(self):
        return []

    def get_config(self):
        self.validate()

        config = 'apply Service "check_' + self.get_id() + '" {\n'
        config += '  check_command = "command_' + self.__command_name + '_' + self.__check_type + '"\n'
        config += self.get_property_default_config()
        config += self.get_custom_property_config()
        config += self.get_group_config()
        config += Checkable.get_config(self)
        config += '  assign where "check_' + self.get_id() + '" in host.vars.checks\n'
        config += '}\n'

        return config

    def get_group_config(self):

        return ValueMapper.parse_var('groups', self.__service_groups, value_prefix='servicegroup_')

    def get_custom_property_config(self):
        config = ''
        for line in self.get_custom_definitions():
            config += '  ' + line + '\n'

        return config

    def get_property_default_config(self):

        return ValueMapper.get_property_default_config(self, self.__class_name, self.__command_name, 'command')



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Dependency.Dependency import Dependency
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class CheckDependency(Dependency):

    def __init__(self, id):
        Dependency.__init__(self, id)
        self.__parent_service_name = None

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        dependency = None if force_create else ConfigBuilder.get_dependency(id)
        if None is dependency:
            dependency = CheckDependency(id)
            ConfigBuilder.add_dependency(id, dependency)

        return dependency

    def get_allowed_states(self):
        return ['OK', 'Warning', 'Critical', 'Unknown', 'Up', 'Down']

    def get_default_states(self):
        return ['OK', 'Warning']

    def validate(self):
        Dependency.validate(self)
        if None == self.__parent_service_name:
            raise Exception('You have to set a check to depends on on dependency with id "' + self.get_id() + '"')

    def set_check(self, check):
        if isinstance(check, str):
            check = ConfigBuilder.get_check(check)
            if None is check:
                raise Exception('Check does not exist yet!')
            self.__parent_service_name = check
        elif callable(getattr(check, 'get_id', None)):
            return self.set_check(check.get_id())
        else:
            raise Exception('Can only add Check or id of Check!')

        return self

    def get_check(self):
        return self.__parent_service_name

    def get_config(self):
        self.validate()

        config = Dependency.get_config(self)
        config += 'apply Dependency "servicedependency_' + self.get_id() + '" to Service {\n'
        config += '  import "dependency_' + self.get_id() + '"\n'
        config += ValueMapper.parse_var('parent_service_name', self.__parent_service_name, value_prefix='check_')
        config += '  assign where "dependency_' + self.get_id() + '" in service.vars.dependencies\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.NagiosPlugins.CheckHttp import CheckHttp
from icinga2confgen.Utils.DefaultWebserverChecks import DefaultWebserverChecks
from icinga2confgen.ValueChecker import ValueChecker


class DefaultGitChecks(DefaultWebserverChecks):

    def __init__(self, vhostconfig=[], servers=[], checkserver=[], notifications=[]):
        DefaultWebserverChecks.__init__(self, vhostconfig, servers, checkserver, notifications)
        self.__validate_deny_git = True
        self.__validate_deny_gitignore = True
        self.__inherit = True

    def set_inherit(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__inherit = enabled

        return self

    def is_inherit(self):
        return self.__inherit

    def validate_deny_git(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_git = enabled

        return self

    def is_validating_deny_git(self):
        return self.__validate_deny_git

    def validate_deny_gitignore(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_gitignore = enabled

        return self

    def is_validating_deny_gitignore(self):
        return self.__validate_deny_gitignore

    def apply(self):
        if self.__inherit:
            DefaultWebserverChecks.apply(self)

        for config in DefaultWebserverChecks.get_vhostconfigs(self):
            service_baseid = config[0]
            domain = config[1]

            for server in DefaultWebserverChecks.get_servers(self):
                base_id = service_baseid

                if True is self.__validate_deny_git:
                    self.create_git_check('gitdir', service_baseid, base_id, domain, server, '/.git/')

                if True is self.__validate_deny_gitignore:
                    self.create_git_check('gitignore', service_baseid, base_id, domain, server, '/.gitignore')

    def create_git_check(self, name, base_id, service_baseid, domain, server, uri):

        if None is server.get_ipv4() and None is server.get_ipv6():
            raise Exception('It is required to set the ipv4 or ipv6 on the server with id "' +
                            server.get_id() + '", before you can apply this checks!')

        default_access_checks = self.get_default_access_check(service_baseid, server, domain)
        if None is not server.get_ipv4():
            git_check = CheckHttp.create('web_access_deny_' + name + '_ipv4_' + base_id)
            git_check.set_ip(server.get_ipv4()) \
                .set_vhost(domain) \
                .set_uri(uri) \
                .set_ssl(True) \
                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                .set_expect('40') \
                .set_check_interval('6h') \
                .set_display_name(git_check.get_display_name() + ' ' + domain)
            self.apply_check_to_checkserver(git_check, default_access_checks['ipv4'])

        if None is not server.get_ipv6():
            git_check = CheckHttp.create('web_access_deny_' + name + '_ipv6_' + base_id)
            git_check.set_ip(server.get_ipv6()) \
                .set_vhost(domain) \
                .set_uri(uri) \
                .set_ssl(True) \
                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                .set_expect('40') \
                .set_check_interval('6h') \
                .set_display_name(git_check.get_display_name() + ' ' + domain)
            self.apply_check_to_checkserver(git_check, default_access_checks['ipv4'])



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ValueMapper import ValueMapper


class CustomVars:

    def __init__(self):
        self.__custom_vars = []

    def add_custom_var(self, key, value):
        # todo check allowed values
        # todo check key
        self.__custom_vars.append({'key': key, 'value': value})
        return self

    def remove_custom_var(self, key):
        vars = self.__custom_vars
        self.__custom_vars = []
        for var in vars:
            if var['key'] != key:
                self.__custom_vars.append(var)
        return self

    def get_custom_var(self, key):
        for var in self.__custom_vars:
            if var['key'] == key:
                return var['value']

        last_value = None

        for template in self.get_templates():
            if None is not template and callable(getattr(template, 'get_custom_var', None)):
                new_value = template.get_custom_var(key)
                if None is not new_value:
                    last_value = new_value

        return last_value

    def get_custom_vars(self):
        vars = []

        for template in self.get_templates():
            if None is not template and callable(getattr(template, 'get_custom_vars', None)):
                new_vars = template.get_custom_vars()
                for new_var in new_vars:
                    for var in vars:
                        if new_var['key'] == var['key']:
                            vars.remove(var)
                    vars.append(new_var)

        for new_var in self.__custom_vars:
            for var in vars:
                if new_var['key'] == var['key']:
                    vars.remove(var)
            vars.append(new_var)

        return vars

    def get_config(self):
        config = ''

        for custom_var in self.__custom_vars:
            config += ValueMapper.parse_var('vars.' + custom_var['key'], custom_var['value'])

        return config

    def get_templates(self):
        return []



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.HariSekhonNagiosPlugins.YumCommand import YumCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckYum(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckYum', 'yum')
        self.__timeout = 30
        self.__all_updates = False
        self.__warn_any_update = True
        self.__cache_only = False
        self.__no_warn_on_lock = False
        self.__config = None
        self.__repo_enabled = None
        self.__repo_disabled = None
        self.__plugin_disabled = None
        self.set_check_interval('1h')
        self.add_service_group(ServiceGroup.create('updates'))
        self.add_service_group(ServiceGroup.create('yum'))

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_all_updates(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__all_updates = enabled
        return self

    def get_all_updates(self):
        return self.__all_updates

    def set_cache_only(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__cache_only = enabled
        return self

    def get_cache_only(self):
        return self.__cache_only

    def set_no_warn_on_lock(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__no_warn_on_lock = enabled
        return self

    def get_no_warn_on_lock(self):
        return self.__no_warn_on_lock

    def set_warn_any_update(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__warn_any_update = enabled
        return self

    def get_warn_any_update(self):
        return self.__warn_any_update

    def set_yum_config(self, config):
        ValueChecker.is_string(config)
        self.__config = config
        return self

    def get_yum_config(self):
        return self.__config

    def set_repo_enabled(self, repo_enabled):
        ValueChecker.is_string(repo_enabled)
        self.__repo_enabled = repo_enabled
        return self

    def get_repo_enabled(self):
        return self.__repo_enabled

    def set_repo_disabled(self, repo_disabled):
        ValueChecker.is_string(repo_disabled)
        self.__repo_disabled = repo_disabled
        return self

    def get_repo_disabled(self):
        return self.__repo_disabled

    def set_plugin_disabled(self, plugin_disabled):
        ValueChecker.is_string(plugin_disabled)
        self.__plugin_disabled = plugin_disabled
        return self

    def get_plugin_disabled(self):
        return self.__plugin_disabled

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckYum(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('yum'):
            YumCommand.create('yum')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.ProcsCommand import ProcsCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckProcs(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckProcs', 'procs')
        self.__warning_range = None
        self.__critical_range = None
        self.__metric = None
        self.__timeout = 10
        self.__traditional = False
        self.__state = None
        self.__pid = None
        self.__vsz = None
        self.__user = None
        self.__argument = None
        self.__argument_ereg = None
        self.__command = None
        self.__only_non_kernel = False
        self.add_service_group(ServiceGroup.create('procs'))
        self.add_service_group(ServiceGroup.create('system_health'))

    def set_warning_range(self, warning_range):
        ValueChecker.is_string(warning_range)
        self.__warning_range = warning_range
        return self

    def get_warning_range(self):
        return self.__warning_range

    def set_critical_range(self, critical_range):
        ValueChecker.is_string(critical_range)
        self.__critical_range = critical_range
        return self

    def get_critical_range(self):
        return self.__critical_range

    def set_metric(self, metric):
        ValueChecker.is_string(metric)
        self.__metric = metric
        return self

    def get_metric(self):
        return self.__metric

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_traditional(self, traditional):
        ValueChecker.is_bool(traditional)
        self.__traditional = traditional
        return self

    def get_traditional(self):
        return self.__traditional

    def set_state(self, state):
        ValueChecker.is_string(state)
        self.__state = state
        return self

    def get_state(self):
        return self.__state

    def set_pid(self, pid):
        ValueChecker.is_string(pid)
        self.__pid = pid
        return self

    def get_pid(self):
        return self.__pid

    def set_vsz(self, vsz):
        ValueChecker.is_string(vsz)
        self.__vsz = vsz
        return self

    def get_vsz(self):
        return self.__vsz

    def set_user_of_threads(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user_of_threads(self):
        return self.__user

    def set_argument(self, argument):
        ValueChecker.is_string(argument)
        self.__argument = argument
        return self

    def get_argument(self):
        return self.__argument

    def set_argument_ereg(self, argument_ereg):
        ValueChecker.is_string(argument_ereg)
        self.__argument_ereg = argument_ereg
        return self

    def get_argument_ereg(self):
        return self.__argument_ereg

    def set_command(self, command):
        ValueChecker.is_string(command)
        self.__command = command
        return self

    def get_command(self):
        return self.__command

    def set_only_non_kernel(self, only_non_kernel):
        ValueChecker.is_bool(only_non_kernel)
        self.__only_non_kernel = only_non_kernel
        return self

    def get_only_non_kernel(self):
        return self.__only_non_kernel

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckProcs(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('procs'):
            ProcsCommand.create('procs')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.AptCommand import AptCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckApt(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckApt', 'apt')
        self.__timeout = 10
        self.__upgrade = None
        self.__dist_upgrade = None
        self.__no_upgrade = None
        self.__include = None
        self.__exclude = None
        self.__critical = None
        self.__only_critical = None
        self.__packages_warning = None
        self.__update = None
        self.set_check_interval('1h')
        self.add_service_group(ServiceGroup.create('updates'))
        self.add_service_group(ServiceGroup.create('apt'))

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_upgrade(self, opts):
        ValueChecker.is_string(opts)
        self.__upgrade = opts
        return self

    def get_upgrade(self):
        return self.__upgrade

    def set_dist_upgrade(self, opts):
        ValueChecker.is_string(opts)
        self.__dist_upgrade = opts
        return self

    def get_dist_upgrade(self):
        return self.__dist_upgrade

    def set_no_upgrade(self, opts):
        ValueChecker.is_string(opts)
        self.__no_upgrade = opts
        return self

    def get_no_upgrade(self):
        return self.__no_upgrade

    def set_include(self, expr):
        ValueChecker.is_string(expr)
        self.__include = expr
        return self

    def get_include(self):
        return self.__include

    def set_exclude(self, expr):
        ValueChecker.is_string(expr)
        self.__exclude = expr
        return self

    def get_exclude(self):
        return self.__exclude

    def set_critical(self, expr):
        ValueChecker.is_string(expr)
        self.__critical = expr
        return self

    def get_critical(self):
        return self.__critical

    def set_only_critical(self, enable):
        ValueChecker.is_bool(enable)
        self.__only_critical = enable
        return self

    def get_only_critical(self):
        return self.__only_critical

    def set_packages_warning(self, count):
        ValueChecker.is_number(count)
        self.__packages_warning = count
        return self

    def get_packages_warning(self):
        return self.__packages_warning

    def set_update(self, opts):
        ValueChecker.is_string(opts)
        self.__update = opts
        return self

    def get_update(self):
        return self.__update

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckApt(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('apt'):
            AptCommand.create('apt')

        return check

    def validate(self):
        pass
